﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using Microsoft.Practices.Composite.Events;
using Infrastructure.Desktop;

namespace Module.StatusBar
{
    public class StatusBarPresentationModel : IStatusBarPresentationModel, INotifyPropertyChanged
    {
        #region IStatusBarPresentationModel Members

        public IStatusBarView View { get; private set; }

        #endregion

        #region Properties

        private string _message;
        public string Message
        {
            get { return _message; }
            set
            {
                if (_message != value)
                {
                    _message = value;
                    PropertyChanged(this, new PropertyChangedEventArgs("Message"));
                }
            }
        }

        #endregion Properties

        private IEventAggregator _eventAggregator;

        public StatusBarPresentationModel(IStatusBarView view, IEventAggregator eventAggregator)
        {
            this.View = view;
            this.View.Model = this;

            this._eventAggregator = eventAggregator;

            //we wnat to know whenever a person is selected so lets subscribe to the person selection changed event
            this._eventAggregator.GetEvent<PersonSelectionChangedEvent>().Subscribe(PersonChanged);

            //we also want to know when a person has been deleted
            this._eventAggregator.GetEvent<PersonDeletedEvent>().Subscribe(PersonDeleted);
        }

        public void PersonChanged(string personName)
        {
            this.Message = string.Format("{0} was selected", personName);
        }

        public void PersonDeleted(string personName)
        {
            this.Message = string.Format("{0} was deleted", personName);
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged = delegate { };

        #endregion
    }
}
